@@ -651,7 +651,7 @@ static void ndllik_sep(int n, double *p, double *df, struct mycallinfo_sep *info
 }
 void mymleGPsep(GPsep* gpsep, double* dmin, double *dmax, double *ab,
 		const unsigned int maxit, int verb, double *p, int *its,
-		char *msg, int *conv)
+		char *msg, unsigned int msg_size, int *conv)
 {
   int lbfgs_verb;
   unsigned int k;
@@ -686,7 +686,7 @@ void mymleGPsep(GPsep* gpsep, double* dmin, double *dmax, double *ab,
   rmse = 0.0;
   for(k=0; k<gpsep->m; k++) rmse += sq(p[k] - dold[k]);
   if(sqrt(rmse/k) < SDEPS) {
-    sprintf(msg, "lbfgs initialized at minima");
+    snprintf(msg, msg_size, "lbfgs initialized at minima");
     *conv = 0;
     its[0] = its[1] = 0;
   }
@@ -714,7 +714,7 @@ void myjmleGPsep(GPsep *gpsep, int maxit, double *dmin, double *dmax,
   /* loop over coordinate-wise iterations */
   *dits = *gits = 0;
   for(i=0; i<100; i++) {
-    mymleGPsep(gpsep, dmin, dmax, dab, maxit, verb, d, dit, msg, dconv);
+    mymleGPsep(gpsep, dmin, dmax, dab, maxit, verb, d, dit, msg, 60, dconv);
     if(dit[1] > dit[0]) dit[0] = dit[1];
     *dits += dit[0];
     mleGPsep_nug(gpsep, grange[0], grange[1], gab, verb, &git);
