@@ -31,7 +31,6 @@
 #include <assert.h>
 #include <Rmath.h>
 
-#define DOUBLE_EPS     DBL_EPSILON
 /*
  * log_determinant_chol:
  *
@@ -65,7 +64,7 @@ double Brent_fmin(double ax, double bx, double (*f)(double, void *),
     double t2, fu, fv, fw, fx, xm, eps, tol1, tol3;
 
 /*  eps is approximately the square root of the relative machine precision. */
-    eps = DOUBLE_EPS;
+    eps = DBL_EPSILON;
     tol1 = eps + 1.;/* the smallest 1.000... > 1 */
     eps = sqrt(eps);
 
